/**
 * 调用摄像头使用方法
 * @param now 选择本地图片时，当前选择图片数
 * @param max 选择本地图片时，最多添加图片数
 * @param graph 拍照点击成功回调
 * @param graph(url) ==>  url:拍照成功后返回的图片路径
 * @param locality  调用本地图片成功回调
 * @param locality(realyUrl,thumbUrl) ==>  realyUrl:真实图片路径  thumbUrl:缩略图路径
 * @constructor
 */
function OpenCamera(now, max, graph, locality) {
    api.actionSheet({
        cancelTitle: '取消',
        buttons: ['拍照', '本地图片']
    }, function(ret, err) {
        if (ret) {
            var index = ret.buttonIndex;
            if (index == 1) {
                api.getPicture({
                    sourceType: 'camera',
                    encodingType: 'jpg',
                    mediaValue: 'pic',
                    destinationType: 'url',
                    allowEdit: false,
                    quality: 50,
                    targetWidth: 1024,
                    saveToPhotoAlbum: true
                }, function(ret, err) {
                    if (ret) {
                        if (ret.data != "") {
                            url = ret.data;
                            graph(url);
                        }
                    }
                });

            } else if (index == 2) {
                var imgMax = max - parseInt(now);
                var UIMediaScanner = api.require('UIMediaScanner');
                UIMediaScanner.open({
                    type: 'picture',
                    column: 4,
                    classify: true,
                    max: imgMax,
                    sort: {
                        key: 'time',
                        order: 'desc'
                    },
                    texts: {
                        stateText: '已选择*项',
                        cancelText: '取消',
                        finishText: '完成',
                        selectedMaxText: '超过*个了！',
                        okBtnText: '我知道了',
                        classifyTitle: '相簿'
                    },
                    styles: {
                        bg: '#fff',
                        mark: {
                            icon: '',
                            position: 'bottom_left',
                            size: 20
                        },
                        nav: {
                            bg: '#eee',
                            stateColor: '#000',
                            stateSize: 18,
                            cancelBg: 'rgba(0,0,0,0)',
                            cancelColor: '#000',
                            cancelSize: 18,
                            finishBg: 'rgba(0,0,0,0)',
                            finishColor: '#000',
                            finishSize: 18
                        }
                    },
                    exchange: true,
                }, function(ret) {
                    if (ret) {
                        if (ret.eventType == "confirm") {
                            /*点击了确认*/
                            RET_LIST_I = 0;
                            RET_LIST_LENGHT = ret.list.length;
                            RET_LIST = ret.list;
                            if (RET_LIST.length == 0) {
                                return;
                            }
                            EditPhoto(RET_LIST[RET_LIST_I].path, RET_LIST[RET_LIST_I].thumbPath, locality);
                        }
                    }
                });
            }
        } else {
            showtoastspan(err);
        }
    });
}

var RET_LIST_I = 0; //当前索引值
var RET_LIST_LENGHT = 0; //图片数组长度
var RET_LIST; //用于存储选择的图片信息
/*解决调用模块异步的问题*/
function EditPhoto(ParaPath, ParaThumbPath, locality) {
    var UIMediaScanner = api.require('UIMediaScanner');
    var imageFilter = api.require('imageFilter');
    var imgPath = ParaPath; //真实图片
    var thumbPath = ParaThumbPath; //缩略图
    var filename = Date.parse(new Date()) + RET_LIST_I + ".jpg";
    var target_w = 1024; //限制高度
    var resPath; //用于存放处理图片路径
    /*选择图片*/
    if (api.systemType == "ios") {
        UIMediaScanner.transPath({
            path: imgPath
        }, function(res, err) {
            resPath = res.path;
            /*进行处理*/
            imageFilter.getAttr({
                path: resPath
            }, function(ret, err) {
                if (ret.status) {
                    if (ret.width < target_w) {
                        target_w = ret.width;
                    }
                    var original_w = ret.width;
                    var original_h = ret.height;
                    var scale = original_w / target_w;
                    var target_h = Math.round(original_h / scale);
                    imageFilter.compress({
                        img: resPath,
                        quality: 0.5,
                        size: {
                            w: target_w,
                            h: target_h
                        },
                        save: {
                            album: false,
                            imgPath: api.cacheDir + '/upload/',
                            imgName: filename
                        }
                    }, function(ret, err) {
                        locality(api.cacheDir + '/upload/' + filename, thumbPath);
                        RET_LIST_I++;
                        if (RET_LIST_I < RET_LIST_LENGHT) {
                            EditPhoto(RET_LIST[RET_LIST_I].path, RET_LIST[RET_LIST_I].thumbPath, locality);
                        }
                    });
                }
            });
        });
    } else {
        resPath = imgPath;
        /*进行处理*/
        imageFilter.getAttr({
            path: resPath
        }, function(ret, err) {
            if (ret.status) {
                if (ret.width < target_w) {
                    target_w = ret.width;
                }
                var original_w = ret.width;
                var original_h = ret.height;
                var scale = original_w / target_w;
                var target_h = Math.round(original_h / scale);
                imageFilter.compress({
                    img: resPath,
                    quality: 0.5,
                    size: {
                        w: target_w,
                        h: target_h
                    },
                    save: {
                        album: false,
                        imgPath: api.cacheDir + '/upload/',
                        imgName: filename
                    }
                }, function(ret, err) {
                    locality(api.cacheDir + '/upload/' + filename, thumbPath);
                    RET_LIST_I++;
                    if (RET_LIST_I < RET_LIST_LENGHT) {
                        EditPhoto(RET_LIST[RET_LIST_I].path, RET_LIST[RET_LIST_I].thumbPath, locality);
                    }
                });
            }
        });
    }

}
